@@ -41,7 +41,8 @@ class Configuration(_BaseConfiguration):
         self.release_stage = "production"
         self.notify_release_stages = None
         self.auto_notify = True
-        self.use_ssl = False
+        self.send_code = True
+        self.use_ssl = True
         self.lib_root = get_python_lib()
         self.project_root = os.getcwd()
         self.app_version = None
